#include <stdlib.h>
#include <curses.h>

#include "termset.h"
#include "direction.h"
#include "help.h"

#define CONT				0
#define QUIT				1

int main(int argc, char* argv[])
{
	int done = CONT;
	int dir_mode = ARROW_MODE;
	int input;
	int count;
	Direction direction;

	/* Check command line arguments */
	if (argc > 1)
	{
		for (count = 1; count < argc; count++)
		{
			if (argv[count][0] == '-')
			{
				switch (argv[count][1])
				{
					case 'v':
						dir_mode = VI_MODE;
						break;
					case 'h':
					default:
						cmdline_help();
						return 0;
						break;
				} /* END switch (argv[count][1]) */
			} /* END if (argv[count][0] == '-' */
			else /* if (argv[count][0] != '-') */
			{
				cmdline_help();
				return 0;
			} /* END else if (argv[count][0] != '-') */
		} /* END for (count = 1; count <= argc; count++) */
	} /* END if (argc > 1) */

	/* Set up the game terminal */
	set_gameterm();
	
	/* Reset the terminal whenever we exit */
	atexit(reset_gameterm);	

	/* Game Loop */
	while (!done)
	{
		/* Get input */
		input = getch ();

		direction = check_direction (input, dir_mode);
		switch (direction)
		{
			case dir_left:
				printw ("LEFT\n");
				break;
			case dir_down:
				printw ("DOWN\n");
				break;
			case dir_up:
				printw ("UP\n");
				break;
			case dir_right:
				printw ("RIGHT\n");
				break;
			case dir_none:
			default:
				/* Check for none directional input */
				switch (input)
				{
					case '?':
						display_help();
						break;
					case 'q':
					case 'Q':
						done = QUIT;
						break;
					default:
						break;
				} /* END switch (input) */
		} /* END switch (direction) */
	} /* END Game Loop */

	return 0;
} /* END FUNC main */
